pub enum SqsError {
Build,
Transport {
source: Box<dyn Error + Send + Sync>,
request_id: Option<String>,
},
Timeout {
request_id: Option<String>,
},
Service(Box<dyn Error + Send + Sync>),
InvalidResponse(String),
}Expand description
Errors that can occur during AWS SQS operations.
This enum covers all possible errors when creating SQS clients or processing messages, including SQS client or operation errors, and not found errors.
Variants
Build
Request build failed
Transport
Network/dispatch failure
Timeout
Request timeout
Service(Box<dyn Error + Send + Sync>)
Service error
InvalidResponse(String)
Invalid response